#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is now obsolete and is going to disappear.

"""Iterates over a bunch of .jpg or .cr2 files and matches 
DateTimeOriginal from Exif tag to DateTime in a csv log 
of a GeigerMuellerCounter and writes its value to the UserComment
Exif tag in µS/h"""

from datetime import datetime, timedelta
import os
import shutil
import csv
import argparse
import pytz
import pyexiv2
import gpxpy

# SIFACTOR for GQ Geiger counters

# 300  series: 0.0065   µSv/h / CPM
# 320  series: 0.0065   µSv/h / CPM
# 500  series: 0.0065   µSv/h / CPM
# 500+ series: 0.0065   µSv/h / CPM for the first tube
# 600  series: 0.0065   µSv/h / CPM
# 600+ series: 0.002637 µSv/h / CPM

# Configure argument parser for cli options
parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter, 
                                 description='''A unix-tyle tool that 
    extracts GPS and/or radiation data from GPX/CSV files and writes
    them into the Exif tags of given photos.''')
parser.add_argument('-si', '--sifactor', type=float, default=0.0065, 
                    help='Factor to multiply recorded CPM with.')
parser.add_argument('-tz', '--timezone', type=str, metavar='Timezone', default='utc',
                    help='''Manually set timezone of CSV / and Photo timestamp,
                    defaults to UTC if omitted. This is useful, if the GPS-Logger
                    saves the time incl. timezone''')
parser.add_argument('-d', '--dry', action='store_true', 
                    help='Dry-run, do not actually write anything.')
parser.add_argument('csv', metavar='CSV', type=str, 
                    help='Geiger counter history file in CSV format.')
parser.add_argument('-g', '--gpx', metavar='GPX', type=str,
                    help='GPS track in GPX format')
parser.add_argument('photos', metavar='Photo', type=str, nargs='+', 
                    help='One or multiple photo image files to process.')
parser.add_argument('-o', '--outdir', type=str, default='.', 
                    help='Directory to output processed photos.')

args = parser.parse_args()

# Create timezone datetime object
localtz = pytz.timezone(args.timezone)

# Inform the user about what is going to happen
if args.dry is not None:
    if args.outdir == ".":
        print('Modifying photos in place (overwrite)')
    else:
        print('Modifying photos in', str(args.outdir), '(copy)')
else:
    print('Not modifying anything. Just print what would happen without --dry')

# Print table header
print('{:<15} {:<25} {:<22}'.format('filename', 'date / time', 'Exif UserComment'))

for srcphoto in args.photos:
    # Get image file name out of path
    photo_basename = os.path.basename(srcphoto)

    # Decide whether to modify photo in place or to copy it to outdir first
    # Then set the destination file as 'photo' to work on
    if args.outdir == ".":
        photo = srcphoto
    else:
        # be os aware and use the correct directory delimiter for destfile
        dstphoto = os.path.join(args.outdir, photo_basename)
        # Don't copy image if in dry-run mode
        if args.dry == 'True':
            shutil.copy(srcphoto, dstphoto)
            photo = dstphoto
        else:
            photo = srcphoto

    # Load Exif data from image
    metadata = pyexiv2.ImageMetadata(photo)
    metadata.read()
    tag = metadata['Exif.Photo.DateTimeOriginal']
    # tag.value creates datetime object in pictime
    picnaivetime = tag.value
    # Set timezone
    pictime = picnaivetime.astimezone(localtz)

    # Import GeigerCounter log
    with open(args.csv, "r") as f:
        csvreader = csv.reader(filter(lambda row: row[0] != '#', f), 
                               delimiter=',', skipinitialspace=True)

        for _, csvrawtime, csvrawcpm, _ in csvreader:
            csvnaivetime = datetime.fromisoformat(csvrawtime)
            # Set timezone
            csvtime = csvnaivetime.astimezone(localtz)
            # Process image if its timestamp is found in CSV log (compares 2 datetime objects)
            if csvtime == pictime:
                rad = round(float(csvrawcpm) * args.sifactor, 2)

                # Set key, value for new UserComment
                key = 'Exif.Photo.UserComment'
                new_comment = 'Radiation ☢ ' + str(rad) + ' µS/h'
                metadata[key] = pyexiv2.ExifTag(key, new_comment)
                
                # print found radiation levels
                print('{:<15} {:<25} {:<22}'.format(photo_basename, str(pictime), new_comment))
                # Write Exif tags to file, if not in dry-run mode
                if args.dry == 'True':
                    metadata.write()
                break
        else:
            print('{:<15} {:<25} {:<22}'.format(photo_basename, str(pictime), 'NOT FOUND!'))
    # close CSV file
    f.close()

    # Import GPX track(s)
    if args.gpx is not None:
        gpx_file = open(args.gpx, 'r')
        gpxreader = gpxpy.parse(gpx_file)

        for waypoint in gpxreader.waypoints:
            for track in gpxreader.tracks:
                for segment in track.segments:
                    for point in segment.points:
                        # datetimes match with 1 minute precision
                        delta = timedelta(seconds=10)
                        if abs(point.time - pictime) < delta:
                            valuelist = []
                            row = [point.time, point.latitude, point.longitude]
                            valuelist.append(row)
                            print(valuelist)
                            #print(pictime, 'vs.', point.time, 'Delta:', pictime - point.time)
#                        print('Point at ({0},{1}) -> {2}'.format(point.latitude, point.longitude, point.time))
